% Auto-generated chapter 28 for nasai
% Hadiths in this chapter: 33

\hadithdefcmd{nasai}{3561}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ الْوَاحِدِ، قَالَ حَدَّثَنَا مَرْوَانُ، - وَهُوَ ابْنُ مُحَمَّدٍ - قَالَ حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ صَالِحِ بْنِ صَبِيحٍ الْمُرِّيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي عَبْلَةَ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجُرَشِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ سَلَمَةَ بْنِ نُفَيْلٍ الْكِنْدِيِّ، قَالَ كُنْتُ جَالِسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَذَالَ النَّاسُ الْخَيْلَ وَوَضَعُوا السِّلاَحَ وَقَالُوا لاَ جِهَادَ قَدْ وَضَعَتِ الْحَرْبُ أَوْزَارَهَا فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَجْهِهِ وَقَالَ ‏ "‏ كَذَبُوا الآنَ الآنَ جَاءَ الْقِتَالُ وَلاَ يَزَالُ مِنْ أُمَّتِي أُمَّةٌ يُقَاتِلُونَ عَلَى الْحَقِّ وَيُزِيغُ اللَّهُ لَهُمْ قُلُوبَ أَقْوَامٍ وَيَرْزُقُهُمْ مِنْهُمْ حَتَّى تَقُومَ السَّاعَةُ وَحَتَّى يَأْتِيَ وَعْدُ اللَّهِ وَالْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ وَهُوَ يُوحَى إِلَىَّ أَنِّي مَقْبُوضٌ غَيْرَ مُلَبَّثٍ وَأَنْتُمْ تَتَّبِعُونِي أَفْنَادًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ وَعُقْرُ دَارِ الْمُؤْمِنِينَ الشَّامُ ‏"‏ ‏.‏\hadithno{3561}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Salamah bin Nufail Al-Kindi said:"I was sitting with the Messenger of Allah when a man said: 'O Messenger of Allah! The people have lost interest in horses and put down their weapons, and they say there is no Jihad, and that war has ended.' The Messenger of Allah turned to face him and said: 'They are lying, now the fighting is to come. There will always be a group among my Ummah who will fight for the truth, for whom Allah will cause some people to deviate, and grant them provision from them, until the Hour begins and until the promise of Allah comes. Goodness is tied to the forelocks of horses until the Day of Resurrection. It has been revealed to me that I am going to die and will not stay long, and you will follow me group after group, striking one another's necks. And the place of safety for the believers is Ash-Sham}}
\hadithdefcmd{nasai}{3562}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبُ بْنُ مُوسَى، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، - يَعْنِي الْفَزَارِيَّ - عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الْخَيْلُ ثَلاَثَةٌ فَهِيَ لِرَجُلٍ أَجْرٌ وَهِيَ لِرَجُلٍ سَتْرٌ وَهِيَ عَلَى رَجُلٍ وِزْرٌ فَأَمَّا الَّذِي هِيَ لَهُ أَجْرٌ فَالَّذِي يَحْتَبِسُهَا فِي سَبِيلِ اللَّهِ فَيَتَّخِذُهَا لَهُ وَلاَ تُغَيِّبُ فِي بُطُونِهَا شَيْئًا إِلاَّ كُتِبَ لَهُ بِكُلِّ شَىْءٍ غَيَّبَتْ فِي بُطُونِهَا أَجْرٌ وَلَوْ عَرَضَتْ لَهُ مَرْجٌ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3562}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'There is goodness tied to the forelocks of horses until the Day of Resurrection. And horses are of three types: Those that bring reward to man, those that are a means of protection for a man, and those that are a burden (of sin) for a man. As for those that bring reward, they are kept for the cause of Allah and for Jihad. No fodder enters their stomach but for everything that enters their stomachs, reward is written for him, even if he puts them out to pasture.'" And he quoted the Hadith}}
\hadithdefcmd{nasai}{3563}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِرَجُلٍ أَجْرٌ وَلِرَجُلٍ سَتْرٌ وَعَلَى رَجُلٍ وِزْرٌ فَأَمَّا الَّذِي هِيَ لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ فَأَطَالَ لَهَا فِي مَرْجٍ أَوْ رَوْضَةٍ فَمَا أَصَابَتْ فِي طِيَلِهَا ذَلِكَ فِي الْمَرْجِ أَوِ الرَّوْضَةِ كَانَ لَهُ حَسَنَاتٌ وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا ذَلِكَ فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كَانَتْ آثَارُهَا ‏"‏ ‏.‏ وَفِي حَدِيثِ الْحَارِثِ ‏"‏ وَأَرْوَاثُهَا حَسَنَاتٍ لَهُ وَلَوْ أَنَّهَا مَرَّتْ بِنَهَرٍ فَشَرِبَتْ مِنْهُ وَلَمْ يُرِدْ أَنْ تُسْقَى كَانَ ذَلِكَ حَسَنَاتٍ فَهِيَ لَهُ أَجْرٌ وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَتَعَفُّفًا وَلَمْ يَنْسَ حَقَّ اللَّهِ عَزَّ وَجَلَّ فِي رِقَابِهَا وَلاَ ظُهُورِهَا فَهِيَ لِذَلِكَ سَتْرٌ وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِيَاءً وَنِوَاءً لأَهْلِ الإِسْلاَمِ فَهِيَ عَلَى ذَلِكَ وِزْرٌ ‏"‏ ‏.‏ وَسُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْحَمِيرِ فَقَالَ ‏"‏ لَمْ يَنْزِلْ عَلَىَّ فِيهَا شَىْءٌ إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏ فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ ‏\}‏ ‏"‏ ‏.‏\hadithno{3563}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Horses may bring reward to a man, or they may be a means of protection, or they may be a burden (of sin). As for that which brings reward, it is a man who keeps it for the cause of Allah and ties it with a long rope in a pasture or a garden; whatever it eats or drinks in that pasture or garden will count as good deeds for him. If it breaks its rope and jumps over one or two hills, its footsteps" -and according to the Hadith of Al-Harith, "its dung will count as good deeds for him. If it passes by a river and drinks from it, even though (its owner) did not intend to give it water from that river, that will also bring him reward. If a man keeps a horse in order to earn an independent living and avoid asking others for help, and he does not forget his duty toward Allah with regard to their (the horses') necks and backs, then they will be a means of protection for him. If a man keeps horses out of pride, to show off before others and to fight the Muslims, then that will be a burden (of sin) for him." The Prophet was asked about donkeys and he said: "Nothing has been revealed to me concerning them except this Verse which is comprehensive in meaning: 'So whosoever does good equal to the weight of an atom (or a small ant) shall see it. And whosoever does evil equal to the weight of an atom (or a small ant) shall see it}}
\hadithdefcmd{nasai}{3564}{أَخْبَرَنِي أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ لَمْ يَكُنْ شَىْءٌ أَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ النِّسَاءِ مِنَ الْخَيْلِ ‏.‏\hadithno{3564}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"There was nothing dearer to the Messenger of Allah after women than horses}}
\hadithdefcmd{nasai}{3565}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الْبَزَّازُ، هِشَامُ بْنُ سَعِيدٍ الطَّالْقَانِيُّ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ الأَنْصَارِيُّ، عَنْ عَقِيلِ بْنِ شَبِيبٍ، عَنْ أَبِي وَهْبٍ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِأَسْمَاءِ الأَنْبِيَاءِ وَأَحَبُّ الأَسْمَاءِ إِلَى اللَّهِ عَزَّ وَجَلَّ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ وَارْتَبِطُوا الْخَيْلَ وَامْسَحُوا بِنَوَاصِيهَا وَأَكْفَالِهَا وَقَلِّدُوهَا وَلاَ تُقَلِّدُوهَا الأَوْتَارَ وَعَلَيْكُمْ بِكُلِّ كُمَيْتٍ أَغَرَّ مُحَجَّلٍ أَوْ أَشْقَرَ أَغَرَّ مُحَجَّلٍ أَوْ أَدْهَمَ أَغَرَّ مُحَجَّلٍ ‏"‏ ‏.‏\hadithno{3565}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Wahb, who was a Companion of the Prophet, said:"The Messenger of Allah said: 'Call (your children) by the names of the prophets. And the most beloved names to Allah, the Mighty and Sublime, are 'Abdullah and 'Abdur-Rahman. Keep horses; wipe their forelocks and posteriors, and prepare them for Jihad, but do not prepare them to seek vengeance for people killed during the Jahiliyyah. You should seek out Kumait, horses with a white mark on the face and white feet, or red with a white mark on the face and white feet, or black with a white mark on the face and white feet}}
\hadithdefcmd{nasai}{3566}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، ح وَأَنْبَأَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَكْرَهُ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏ وَاللَّفْظُ لإِسْمَاعِيلَ ‏.‏\hadithno{3566}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:The Prophet used to dislike the Shikal among horses. And the wording is that of Isma'il}}
\hadithdefcmd{nasai}{3567}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سَلْمُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَرِهَ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الشِّكَالُ مِنَ الْخَيْلِ أَنْ تَكُونَ ثَلاَثُ قَوَائِمَ مُحَجَّلَةً وَوَاحِدَةٌ مُطْلَقَةً أَوْ تَكُونَ الثَّلاَثَةُ مُطْلَقَةً وَرِجْلٌ مُحَجَّلَةً وَلَيْسَ يَكُونُ الشِّكَالُ إِلاَّ فِي رِجْلٍ وَلاَ يَكُونُ فِي الْيَدِ ‏.‏\hadithno{3567}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet used to dislike the Shikal among horses}}
\hadithdefcmd{nasai}{3568}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ مَنْصُورٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي ثَلاَثَةٍ الْمَرْأَةِ وَالْفَرَسِ وَالدَّارِ ‏"‏ ‏.‏\hadithno{3568}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim, from his father, that the Prophet said:"Omens are only in three things: a woman, a horse or a house}}
\hadithdefcmd{nasai}{3569}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏\hadithno{3569}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah said:"Omens are in houses, women and horses}}
\hadithdefcmd{nasai}{3570}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ يَكُ فِي شَىْءٍ فَفِي الرَّبْعَةِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏\hadithno{3570}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah said:"If there are (omens) in anything, they are in houses, women and horses}}
\hadithdefcmd{nasai}{3571}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسًا، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي أَبُو التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَرَكَةُ فِي نَوَاصِي الْخَيْلِ ‏"‏ ‏.‏\hadithno{3571}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'Blessing is in the forelocks of horses}}
\hadithdefcmd{nasai}{3572}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْتِلُ نَاصِيَةَ فَرَسٍ بَيْنَ أُصْبُعَيْهِ وَيَقُولُ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْغَنِيمَةُ ‏"‏ ‏.‏\hadithno{3572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jarir said:"I saw the Messenger of Allah twisting the forelock of a horse with his two fingers, and saying: 'Goodness is tied to the forelocks of horses until the Day of Resurrection: Reward and spoils of war}}
\hadithdefcmd{nasai}{3573}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3573}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"There is goodness in the forelocks of horses until the Day of Resurrection}}
\hadithdefcmd{nasai}{3574}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنْ عَامِرٍ، عَنْ عُرْوَةَ الْبَارِقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3574}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Urwah Al-Bariqi said:"The Messenger of Allah said: 'Goodness is tied to the forelocks of horses until the Day of Resurrection}}
\hadithdefcmd{nasai}{3575}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ أَبِي الْجَعْدِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏ ‏.‏\hadithno{3575}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Urwah bin Abi Al-Ja'd that he heard the Prophet say:"Goodness is tied to the forelocks of horses until the Day of Resurrection: Reward and spoils of war}}
\hadithdefcmd{nasai}{3576}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏ ‏.‏\hadithno{3576}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Urwah said that he heard the Messenger of Allah say:"Goodness is tied to the forelocks of horses until the Day of Resurrection: Reward and spoils of war}}
\hadithdefcmd{nasai}{3577}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي حُصَيْنٌ، وَعَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ، أَنَّهُمَا سَمِعَا الشَّعْبِيَّ، يُحَدِّثُ عَنْ عُرْوَةَ بْنِ أَبِي الْجَعْدِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏ ‏.‏\hadithno{3577}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Urwah bin Abi Al-Ja'd that the Prophet said:"Goodness is tied to the forelocks of horses until the Day of Resurrection: Reward and spoils of war}}
\hadithdefcmd{nasai}{3578}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ مُجَالِدٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، قَالَ حَدَّثَنِي أَبُو سَلاَّمٍ الدِّمَشْقِيُّ، عَنْ خَالِدِ بْنِ يَزِيدَ الْجُهَنِيِّ، قَالَ كَانَ عُقْبَةُ بْنُ عَامِرٍ يَمُرُّ بِي فَيَقُولُ يَا خَالِدُ اخْرُجْ بِنَا نَرْمِي ‏.‏ فَلَمَّا كَانَ ذَاتَ يَوْمٍ أَبْطَأْتُ عَنْهُ فَقَالَ يَا خَالِدُ تَعَالَ أُخْبِرْكَ بِمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ يُدْخِلُ بِالسَّهْمِ الْوَاحِدِ ثَلاَثَةَ نَفَرٍ الْجَنَّةَ صَانِعَهُ يَحْتَسِبُ فِي صُنْعِهِ الْخَيْرَ وَالرَّامِيَ بِهِ وَمُنَبِّلَهُ وَارْمُوا وَارْكَبُوا وَأَنْ تَرْمُوا أَحَبُّ إِلَىَّ مِنْ أَنْ تَرْكَبُوا وَلَيْسَ اللَّهْوُ إِلاَّ فِي ثَلاَثَةٍ تَأْدِيبِ الرَّجُلِ فَرَسَهُ وَمُلاَعَبَتِهِ امْرَأَتَهُ وَرَمْيِهِ بِقَوْسِهِ وَنَبْلِهِ وَمَنْ تَرَكَ الرَّمْىَ بَعْدَ مَا عَلِمَهُ رَغْبَةً عَنْهُ فَإِنَّهَا نِعْمَةٌ كَفَرَهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ كَفَرَ بِهَا ‏"‏ ‏.‏\hadithno{3578}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Khalid bin Yazid Al-Juhani said:"Uqbah bin 'Amir used to pass by me and say: 'O Khalid, let us go out and shoot arrows.' One day I came late and he said: 'O Khalid, come and I will tell you what the Messenger of Allah said.' So I went to him and he said: 'The Messenger of Allah said: Allah will admit three people to Paradise because of one arrow: The one who makes it seeking good thereby, the one who shoots it and the one who hands it to him. So shoot and ride, and if you shoot that is dearer to me than if you ride. And play is only in three things: A man training his horse, and playing with his wife, and shooting with his bow and arrow. Whoever gives up shooting after learning it because he is no longer interested in it, that is a blessing for which he is ungrateful -or that he has rejected}}
\hadithdefcmd{nasai}{3579}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، عَنْ مُعَاوِيَةَ بْنِ حُدَيْجٍ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ فَرَسٍ عَرَبِيِّ إِلاَّ يُؤْذَنُ لَهُ عِنْدَ كُلِّ سَحَرٍ بِدَعْوَتَيْنِ اللَّهُمَّ خَوَّلْتَنِي مَنْ خَوَّلْتَنِي مِنْ بَنِي آدَمَ وَجَعَلْتَنِي لَهُ فَاجْعَلْنِي أَحَبَّ أَهْلِهِ وَمَالِهِ إِلَيْهِ أَوْ مِنْ أَحَبِّ مَالِهِ وَأَهْلِهِ إِلَيْهِ ‏"‏ ‏.‏\hadithno{3579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said: 'There is no Arabian horse but it is allowed to offer two supplications every Sahar (end of the night): O Allah, You have caused me to be owned by whoever You wanted among the sons of Adam, and you have made me belong to him. Make me the dearest of his family and wealth to him, or among the dearest of his family and wealth to him}}
\hadithdefcmd{nasai}{3580}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنِ ابْنِ زُرَيْرٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه قَالَ أُهْدِيَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَغْلَةٌ فَرَكِبَهَا فَقَالَ عَلِيٌّ لَوْ حَمَلْنَا الْحَمِيرَ عَلَى الْخَيْلِ لَكَانَتْ لَنَا مِثْلَ هَذِهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا يَفْعَلُ ذَلِكَ الَّذِينَ لاَ يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{3580}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ali bin Abi Talib, may Allah be pleased with him, said:"A mule was given as a gift to the Messenger of Allah and he rode it." 'Ali said: "If we mate a donkey with a horse, we will have one like this." The Messenger of Allah said: "That is only done by those who do not know}}
\hadithdefcmd{nasai}{3581}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي جَهْضَمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ فَسَأَلَهُ رَجُلٌ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ قَالَ لاَ ‏.‏ قَالَ فَلَعَلَّهُ كَانَ يَقْرَأُ فِي نَفْسِهِ قَالَ خَمْشًا هَذِهِ شَرٌّ مِنَ الأُولَى إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَبْدٌ أَمَرَهُ اللَّهُ تَعَالَى بِأَمْرِهِ فَبَلَّغَهُ وَاللَّهِ مَا اخْتَصَّنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ دُونَ النَّاسِ إِلاَّ بِثَلاَثَةٍ أَمَرَنَا أَنْ نُسْبِغَ الْوُضُوءَ وَأَنْ لاَ نَأْكُلَ الصَّدَقَةَ وَلاَ نُنْزِيَ الْحُمُرَ عَلَى الْخَيْلِ ‏.‏\hadithno{3581}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Ubaidullah bin 'Abbas said:I was with Ibn 'Abbas and a man asked him: "Did the Messenger of Allah recite during Zuhr and 'Asr?" He said: "No." He said: "Perhaps he used to recite to himself?" He said: "May your face be scratched! This question is worse than the first one. The Messenger of Allah was a slave whose Lord commanded him and he conveyed (the message). By Allah, the Messenger of Allah did not specify anything for us above the people, except for three things: He commanded us to perform Wudu' properly, not to consume charity, and not to mate donkeys with horses}}
\hadithdefcmd{nasai}{3582}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، حَدَّثَنِي طَلْحَةُ بْنُ أَبِي سَعِيدٍ، أَنَّ سَعِيدًا الْمَقْبُرِيَّ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ احْتَبَسَ فَرَسًا فِي سَبِيلِ اللَّهِ إِيمَانًا بِاللَّهِ وَتَصْدِيقًا لِوَعْدِ اللَّهِ كَانَ شِبَعُهُ وَرِيُّهُ وَبَوْلُهُ وَرَوْثُهُ حَسَنَاتٍ فِي مِيزَانِهِ ‏"‏ ‏.‏\hadithno{3582}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Whoever keeps a horse for the cause of Allah out of faith in Allah and believing the promise of Allah, its feed, water, urine and dung will all count as Hasanat in the balance of his deeds}}
\hadithdefcmd{nasai}{3583}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَابَقَ بَيْنَ الْخَيْلِ يُرْسِلُهَا مِنَ الْحَفْيَاءِ وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضْمَرْ وَكَانَ أَمَدُهَا مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ ‏.‏\hadithno{3583}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah organized a horse race and sent them from Al-Hafya' and its finish line was Thaniyyat Al-Wada'; and he organized a race for horses that had not been made lean, and the course stretched from Ath-Thaniyyah to the Masjid of Banu Zuraiq}}
\hadithdefcmd{nasai}{3584}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَابَقَ بَيْنَ الْخَيْلِ الَّتِي قَدْ أُضْمِرَتْ مِنَ الْحَفْيَاءِ وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضْمَرْ مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ وَأَنَّ عَبْدَ اللَّهِ كَانَ مِمَّنْ سَابَقَ بِهَا ‏.‏\hadithno{3584}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah organized a race for horses that had been made lean, from Al-Hafya' and its finish line was Thaniyyat Al-Wada', and he organized another race for horses that had not been made lean, from Ath-Thaniyyah to the Masjid of Banu Zuraiq, and 'Abdullah was among those who took part in the race}}
\hadithdefcmd{nasai}{3585}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ نَافِعِ بْنِ أَبِي نَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ سَبَقَ إِلاَّ فِي نَصْلٍ أَوْ حَافِرٍ أَوْ خُفٍّ ‏"‏ ‏.‏\hadithno{3585}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There should be no awards (for victory in a competition) except for arrows, camels or horses}}
\hadithdefcmd{nasai}{3586}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدِ اللَّهِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ نَافِعِ بْنِ أَبِي نَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ سَبَقَ إِلاَّ فِي نَصْلٍ أَوْ خُفٍّ أَوْ حَافِرٍ ‏"‏ ‏.‏\hadithno{3586}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There should be no awards (for victory in a competition) except on arrows, camels or horses}}
\hadithdefcmd{nasai}{3587}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي عَبْدِ اللَّهِ، مَوْلَى الْجُنْدَعِيِّينَ عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ لاَ يَحِلُّ سَبَقٌ إِلاَّ عَلَى خُفٍّ أَوْ حَافِرٍ ‏.‏\hadithno{3587}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"No award (for victory in a competition) is permissible except over camels or horses}}
\hadithdefcmd{nasai}{3588}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ كَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم نَاقَةٌ تُسَمَّى الْعَضْبَاءَ لاَ تُسْبَقُ فَجَاءَ أَعْرَابِيٌّ عَلَى قَعُودٍ فَسَبَقَهَا فَشَقَّ عَلَى الْمُسْلِمِينَ فَلَمَّا رَأَى مَا فِي وُجُوهِهِمْ قَالُوا يَا رَسُولَ اللَّهِ سُبِقَتِ الْعَضْبَاءُ ‏.‏ قَالَ ‏ "‏ إِنَّ حَقًّا عَلَى اللَّهِ أَنْ لاَ يَرْتَفِعَ مِنَ الدُّنْيَا شَىْءٌ إِلاَّ وَضَعَهُ ‏"‏ ‏.‏\hadithno{3588}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah had a she-camel called Al-'Adba' which could not be beaten. One day a Bedouin came on a riding-camel and beat her (in a race). The Muslims were upset by that, and when he saw the expressions on their faces they said: 'O Messenger of Allah, Al-'Adba' has been beaten.' He said: 'It is a right upon Allah that nothing is raised in this world except He lowers it}}
\hadithdefcmd{nasai}{3589}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي الْحَكَمِ، - مَوْلًى لِبَنِي لَيْثٍ - عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ سَبَقَ إِلاَّ فِي خُفٍّ أَوْ حَافِرٍ ‏"‏ ‏.‏\hadithno{3589}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There should be no awards (for victory in a competition) except over camels or horses}}
\hadithdefcmd{nasai}{3590}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا حُمَيْدٌ، قَالَ حَدَّثَنَا الْحَسَنُ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ شِغَارَ فِي الإِسْلاَمِ وَمَنِ انْتَهَبَ نُهْبَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Imran bin Husain that the Messenger of Allah said:"There is no 'bringing', no 'avoidance' and no Shighar in Islam, and whoever robs is not one of us}}
\hadithdefcmd{nasai}{3591}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي قَزَعَةَ، عَنِ الْحَسَنِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ جَلَبَ وَلاَ جَنَبَ وَلاَ شِغَارَ فِي الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{3591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Imran bin Husain that the Messenger of Allah said:"There is no 'bringing', no 'avoidance' and no Shighar in Islam}}
\hadithdefcmd{nasai}{3592}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَى شُعْبَةُ، قَالَ حَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَابَقَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْرَابِيٌّ فَسَبَقَهُ فَكَأَنَّ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَدُوا فِي أَنْفُسِهِمْ مِنْ ذَلِكَ فَقِيلَ لَهُ فِي ذَلِكَ فَقَالَ ‏ "‏ حَقٌّ عَلَى اللَّهِ أَنْ لاَ يَرْفَعَ شَىْءٌ نَفْسَهُ فِي الدُّنْيَا إِلاَّ وَضَعَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{3592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah raced with a Bedouin and (the latter) won. It was as if the Companions of the Messenger of Allah were upset by this, so he said: 'It is a right upon Allah that there is nothing that raises itself in this world except that He lowers it}}
\hadithdefcmd{nasai}{3593}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ جَدِّهِ، أَنَّهُ كَانَ يَقُولُ ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ خَيْبَرَ لِلزُّبَيْرِ بْنِ الْعَوَّامِ أَرْبَعَةَ أَسْهُمٍ سَهْمًا لِلزُّبَيْرِ وَسَهْمًا لِذِي الْقُرْبَى لِصَفِيَّةَ بِنْتِ عَبْدِ الْمُطَّلِبِ أُمِّ الزُّبَيْرِ وَسَهْمَيْنِ لِلْفَرَسِ ‏.‏\hadithno{3593}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Yahya bin 'Abbad bin 'Abdullah bin Az-Zubair, from his grandfather, that he used to say:"In the year of Khaibar, the Messenger of Allah allocated four shares to Az-Zubair bin Al-'Awwam: A share of Az-Zubair, a share for the relatives of Safiyyah bint 'Abdul-Muttalib, the mother of Az-Zubair, and two shares for the horse}}
